==> bibledit_1.9.orig.tar.gz: bibledit-1.9/src/clean.cpp <==
/*
** Copyright (C) 2003-2006 Teus Benschop.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/


#include "utilities.h"
#include "clean.h"
#include "usfmtools.h"


#define MARKER_COUNT 102
char *markers_that_dont_split[MARKER_COUNT] =
{ "th1", "th2", "th3", "th4", "thr1", "thr2", "thr3", "thr4", 
  "tc1", "tc2", "tc3", "tc4", "tcr1", "tcr2", "tcr3", "tcr4", 
  "f",   "fe",   "fm",  "fr",  "fk",  "fq",  "fqa",  "fl",  "fp",  "fv",  "ft",  "fdc",
  "f*",  "fe*",  "fm*", "fr*", "fk*", "fq*", "fqa*", "fl*", "fp*", "fv*", "ft*", "fdc*",
  "x",  "xo",  "xk",  "xq",  "xt",  "xdc", 
  "x*", "xo*", "xk*", "xq*", "xt*", "xdc*", 
  "qt",  "nd",  "tl",  "dc",  "bk",  "sig",  "pn",  "wj",  "k",  "sls",  "ord",  "add",  "lit",
  "qt*", "nd*", "tl*", "dc*", "bk*", "sig*", "pn*", "wj*", "k*", "sls*", "ord*", "add*", "lit*",
  "no",  "bd",  "it",  "bdit",  "em",  "sc",
  "no*", "bd*", "it*", "bdit*", "em*", "sc*",
  "fig",  "pro",  "w",  "wh",  "wg",  "ndx",
  "fig*", "pro*", "w*", "wh*", "wg*", "ndx*"
};


CleanUsfm::CleanUsfm (vector <ustring>& input)
// Clean the lines provided: each main USFM starts a new line.
{
  // Markers that split a line.
  set<ustring> splitters;
  for (unsigned int i = 0; i < MARKER_COUNT; i++)
    splitters.insert (markers_that_dont_split[i]);
  
  // Go through all lines.
  for (unsigned int i = 0; i < input.size(); i++) {
    
    // Change tabs to spaces.
    size_t position;
    position = input[i].find ("\t");
    while (position != string::npos) {
      input[i].replace (position, 1, " ");
      position = input[i].find ("\t", position);
    }
    
    // Change multiple spaces to one space.
    position = input[i].find ("  ");
    while (position != string::npos) {
      input[i].replace (position, 2, " ");
      position = input[i].find ("  ");
    }
    
    // Cut into handsome lines, according to the USFM standard.
    vector<ustring> markers;
    markers = usfm_get_all_markers (input[i]);
    for (unsigned int i2 = 0; i2 < markers.size(); i2++) {
      if (splitters.find (markers[i2]) == splitters.end()) {
        split_line_on_marker (markers[i2], input[i]);
      }
    }
    
    // Add a line that does not start with a USFM to the previous one.
    ustring line (input[i]);
    ustring marker = usfm_extract_marker (line);
    if (marker.empty()) {
      lines[lines.size() - 1].append (" ");
      lines[lines.size() - 1].append (input[i]);
      continue;
    }
    
    // Separate and trim these lines.
    position = input[i].find ("\n");
    while (position != string::npos) {
      ustring line = input[i].substr (0, position);
      line = trim (line);
      if (!line.empty())
        lines.push_back (line);
      input[i].erase (0, ++position);
      position = input[i].find ("\n");
    }
    
    // Add to output.
    if (!input[i].empty())
      lines.push_back (trim (input[i]));
  }
}

==> bibledit-2.0.tar.gz: bibledit-2.0/src/clean.cpp <==
/*
** Copyright (C) 2003-2006 Teus Benschop.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/


#include "utilities.h"
#include "clean.h"
#include "usfmtools.h"


#define MARKER_COUNT 102
char *markers_that_dont_split[MARKER_COUNT] =
{ "th1", "th2", "th3", "th4", "thr1", "thr2", "thr3", "thr4", 
  "tc1", "tc2", "tc3", "tc4", "tcr1", "tcr2", "tcr3", "tcr4", 
  "f",   "fe",   "fm",  "fr",  "fk",  "fq",  "fqa",  "fl",  "fp",  "fv",  "ft",  "fdc",
  "f*",  "fe*",  "fm*", "fr*", "fk*", "fq*", "fqa*", "fl*", "fp*", "fv*", "ft*", "fdc*",
  "x",  "xo",  "xk",  "xq",  "xt",  "xdc", 
  "x*", "xo*", "xk*", "xq*", "xt*", "xdc*", 
  "qt",  "nd",  "tl",  "dc",  "bk",  "sig",  "pn",  "wj",  "k",  "sls",  "ord",  "add",  "lit",
  "qt*", "nd*", "tl*", "dc*", "bk*", "sig*", "pn*", "wj*", "k*", "sls*", "ord*", "add*", "lit*",
  "no",  "bd",  "it",  "bdit",  "em",  "sc",
  "no*", "bd*", "it*", "bdit*", "em*", "sc*",
  "pro",  "w",  "wh",  "wg",  "ndx",
  "pro*", "w*", "wh*", "wg*", "ndx*",
  "n", "n*" // These two are used in old projects.
};


CleanUsfm::CleanUsfm (vector <ustring>& input)
// Clean the lines provided: each main USFM starts a new line.
{
  // Markers that split a line.
  set<ustring> splitters;
  for (unsigned int i = 0; i < MARKER_COUNT; i++)
    splitters.insert (markers_that_dont_split[i]);
  
  // Go through all lines.
  for (unsigned int i = 0; i < input.size(); i++) {
    
    // Change tabs to spaces.
    size_t position;
    position = input[i].find ("\t");
    while (position != string::npos) {
      input[i].replace (position, 1, " ");
      position = input[i].find ("\t", position);
    }
    
    // Change multiple spaces to one space.
    position = input[i].find ("  ");
    while (position != string::npos) {
      input[i].replace (position, 2, " ");
      position = input[i].find ("  ");
    }
    
    // Cut into handsome lines, according to the USFM standard.
    vector<ustring> markers;
    markers = usfm_get_all_markers (input[i]);
    for (unsigned int i2 = 0; i2 < markers.size(); i2++) {
      if (splitters.find (markers[i2]) == splitters.end()) {
        split_line_on_marker (markers[i2], input[i]);
      }
    }
    
    // Add a line that does not start with a USFM to the previous one.
    ustring line (input[i]);
    ustring marker = usfm_extract_marker (line);
    if (marker.empty()) {
      lines[lines.size() - 1].append (" ");
      lines[lines.size() - 1].append (input[i]);
      continue;
    }
    
    // Separate and trim these lines.
    position = input[i].find ("\n");
    while (position != string::npos) {
      ustring line = input[i].substr (0, position);
      line = trim (line);
      if (!line.empty())
        lines.push_back (line);
      input[i].erase (0, ++position);
      position = input[i].find ("\n");
    }
    
    // Add to output.
    if (!input[i].empty())
      lines.push_back (trim (input[i]));
  }
}
